@@ -99,6 +99,16 @@ QStringList Application::filenames()
   return returnValue;
 }
 
+/* inline void Application::setIsUnityThere( bool iut )
+{
+  _isUnityThere = iut;
+}
+
+inline bool Application::isUnityThere()
+{
+  return _isUnityThere;
+} */
+
 QList<Application::recentFile> Application::recentFiles()
 {
   return _recentFiles;
