@@ -49,6 +49,8 @@ public:
   QStringList titles();
   QStringList filenames();
   EditingWindow * currentEditingWindow() { return _currentEditingWindow; }
+  void setIsUnityThere( bool iut ) { _isUnityThere = iut; }
+  bool isUnityThere() { return _isUnityThere; }
 
 public slots:
   void setRecentFiles( const QStringList &, const QStringList & );
@@ -67,6 +69,7 @@ public slots:
   SuperMenu *superMenu;
 #endif
   EditingWindow *_currentEditingWindow;
+  bool _isUnityThere;
 
 private slots:
   void saveRecentFiles();
