@@ -31,6 +31,7 @@
 #include <QMessageBox>
 #include <QWhatsThis>
 #include <QLabel>
+#include "Application.h"
 
 PrefsDialog::PrefsDialog( QWidget *parent )
   : QDialog( parent )
@@ -40,9 +41,20 @@ PrefsDialog::PrefsDialog( QWidget *parent )
 
   //cbBlogType->setCurrentIndex( cbBlogType->count()-1 );
 
+  // On Mac and Unity, there is always a new window at startup and on Unity,
+  // there is only one mouse action available in the system tray (which
+  // shows the context menu). So these options are redundant.
 #ifdef Q_OS_MAC
   label_10->setVisible( false );
   cbSTI2ClickFunction->setVisible( false );
+#else
+  Application *qtm = qobject_cast<Application *>qApp;
+  if( qtm ) {
+    if( qtm->isUnityThere() ) {
+      label_10->setVisible( false );
+      cbSTI2ClickFunction->setVisible( false );
+    }
+  }
 #endif
 }
 
